package com.bonus.sgzb.material.service;

import com.bonus.sgzb.material.domain.PurchaseCheckInfo;

import java.util.List;

/**
 * 新购验收任务purchase_check_infoService接口
 * 
 * @author bonus
 * @date 2023-12-10
 */
public interface IPurchaseCheckInfoService 
{
    /**
     * 查询新购验收任务purchase_check_info
     * 
     * @param taskId 新购验收任务purchase_check_info主键
     * @return 新购验收任务purchase_check_info
     */
    public PurchaseCheckInfo selectPurchaseCheckInfoByTaskId(Long taskId);

    /**
     * 查询新购验收任务purchase_check_info列表
     * 
     * @param purchaseCheckInfo 新购验收任务purchase_check_info
     * @return 新购验收任务purchase_check_info集合
     */
    public List<PurchaseCheckInfo> selectPurchaseCheckInfoList(PurchaseCheckInfo purchaseCheckInfo);

    /**
     * 新增新购验收任务purchase_check_info
     * 
     * @param purchaseCheckInfo 新购验收任务purchase_check_info
     * @return 结果
     */
    public int insertPurchaseCheckInfo(PurchaseCheckInfo purchaseCheckInfo);

    /**
     * 修改新购验收任务purchase_check_info
     * 
     * @param purchaseCheckInfo 新购验收任务purchase_check_info
     * @return 结果
     */
    public int updatePurchaseCheckInfo(PurchaseCheckInfo purchaseCheckInfo);

    /**
     * 批量删除新购验收任务purchase_check_info
     * 
     * @param taskIds 需要删除的新购验收任务purchase_check_info主键集合
     * @return 结果
     */
    public int deletePurchaseCheckInfoByTaskIds(Long[] taskIds);

    /**
     * 删除新购验收任务purchase_check_info信息
     * 
     * @param taskId 新购验收任务purchase_check_info主键
     * @return 结果
     */
    public int deletePurchaseCheckInfoByTaskId(Long taskId);
}
